@@ -5,13 +5,14 @@ import sys
 import numpy as np
 from numpy.core.multiarray import _vec_string
 from numpy.testing import (
-    TestCase, run_module_suite, assert_, assert_equal, assert_array_equal
+    run_module_suite, assert_, assert_equal, assert_array_equal, assert_raises,
+    suppress_warnings,
 )
 
 kw_unicode_true = {'unicode': True}  # make 2to3 work properly
 kw_unicode_false = {'unicode': False}
 
-class TestBasic(TestCase):
+class TestBasic(object):
     def test_from_object_array(self):
         A = np.array([['abc', 2],
                       ['long   ', '0123456789']], dtype='O')
@@ -23,7 +24,7 @@ class TestBasic(TestCase):
     def test_from_object_array_unicode(self):
         A = np.array([['abc', u'Sigma \u03a3'],
                       ['long   ', '0123456789']], dtype='O')
-        self.assertRaises(ValueError, np.char.array, (A,))
+        assert_raises(ValueError, np.char.array, (A,))
         B = np.char.array(A, **kw_unicode_true)
         assert_equal(B.dtype.itemsize, 10 * np.array('a', 'U').dtype.itemsize)
         assert_array_equal(B, [['abc', u'Sigma \u03a3'],
@@ -62,7 +63,7 @@ class TestBasic(TestCase):
         def fail():
             np.char.array(A, **kw_unicode_false)
 
-        self.assertRaises(UnicodeEncodeError, fail)
+        assert_raises(UnicodeEncodeError, fail)
 
     def test_unicode_upconvert(self):
         A = np.char.array(['abc'])
@@ -82,59 +83,59 @@ class TestBasic(TestCase):
         assert_equal(A.itemsize, 4)
         assert_(issubclass(A.dtype.type, np.unicode_))
 
-class TestVecString(TestCase):
+class TestVecString(object):
     def test_non_existent_method(self):
 
         def fail():
             _vec_string('a', np.string_, 'bogus')
 
-        self.assertRaises(AttributeError, fail)
+        assert_raises(AttributeError, fail)
 
     def test_non_string_array(self):
 
         def fail():
             _vec_string(1, np.string_, 'strip')
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_invalid_args_tuple(self):
 
         def fail():
             _vec_string(['a'], np.string_, 'strip', 1)
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_invalid_type_descr(self):
 
         def fail():
             _vec_string(['a'], 'BOGUS', 'strip')
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_invalid_function_args(self):
 
         def fail():
             _vec_string(['a'], np.string_, 'strip', (1,))
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_invalid_result_type(self):
 
         def fail():
             _vec_string(['a'], np.integer, 'strip')
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_broadcast_error(self):
 
         def fail():
             _vec_string([['abc', 'def']], np.integer, 'find', (['a', 'd', 'j'],))
 
-        self.assertRaises(ValueError, fail)
+        assert_raises(ValueError, fail)
 
 
-class TestWhitespace(TestCase):
-    def setUp(self):
+class TestWhitespace(object):
+    def setup(self):
         self.A = np.array([['abc ', '123  '],
                            ['789 ', 'xyz ']]).view(np.chararray)
         self.B = np.array([['abc', '123'],
@@ -148,16 +149,16 @@ class TestWhitespace(TestCase):
         assert_(not np.any(self.A < self.B))
         assert_(not np.any(self.A != self.B))
 
-class TestChar(TestCase):
-    def setUp(self):
+class TestChar(object):
+    def setup(self):
         self.A = np.array('abc1', dtype='c').view(np.chararray)
 
     def test_it(self):
         assert_equal(self.A.shape, (4,))
         assert_equal(self.A.upper()[:2].tobytes(), b'AB')
 
-class TestComparisons(TestCase):
-    def setUp(self):
+class TestComparisons(object):
+    def setup(self):
         self.A = np.array([['abc', '123'],
                            ['789', 'xyz']]).view(np.chararray)
         self.B = np.array([['efg', '123  '],
@@ -184,21 +185,21 @@ class TestComparisons(TestCase):
 class TestComparisonsMixed1(TestComparisons):
     """Ticket #1276"""
 
-    def setUp(self):
-        TestComparisons.setUp(self)
+    def setup(self):
+        TestComparisons.setup(self)
         self.B = np.array([['efg', '123  '],
                            ['051', 'tuv']], np.unicode_).view(np.chararray)
 
 class TestComparisonsMixed2(TestComparisons):
     """Ticket #1276"""
 
-    def setUp(self):
-        TestComparisons.setUp(self)
+    def setup(self):
+        TestComparisons.setup(self)
         self.A = np.array([['abc', '123'],
                            ['789', 'xyz']], np.unicode_).view(np.chararray)
 
-class TestInformation(TestCase):
-    def setUp(self):
+class TestInformation(object):
+    def setup(self):
         self.A = np.array([[' abc ', ''],
                            ['12345', 'MixedCase'],
                            ['123 \t 345 \0 ', 'UPPER']]).view(np.chararray)
@@ -230,7 +231,7 @@ class TestInformation(TestCase):
         def fail():
             self.A.endswith('3', 'fdjk')
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
     def test_find(self):
         assert_(issubclass(self.A.find('a').dtype.type, np.integer))
@@ -244,7 +245,7 @@ class TestInformation(TestCase):
         def fail():
             self.A.index('a')
 
-        self.assertRaises(ValueError, fail)
+        assert_raises(ValueError, fail)
         assert_(np.char.index('abcba', 'b') == 1)
         assert_(issubclass(np.char.index('abcba', 'b').dtype.type, np.integer))
 
@@ -288,7 +289,7 @@ class TestInformation(TestCase):
         def fail():
             self.A.rindex('a')
 
-        self.assertRaises(ValueError, fail)
+        assert_raises(ValueError, fail)
         assert_(np.char.rindex('abcba', 'b') == 3)
         assert_(issubclass(np.char.rindex('abcba', 'b').dtype.type, np.integer))
 
@@ -300,11 +301,11 @@ class TestInformation(TestCase):
         def fail():
             self.A.startswith('3', 'fdjk')
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
 
 
-class TestMethods(TestCase):
-    def setUp(self):
+class TestMethods(object):
+    def setup(self):
         self.A = np.array([[' abc ', ''],
                            ['12345', 'MixedCase'],
                            ['123 \t 345 \0 ', 'UPPER']],
@@ -346,8 +347,11 @@ class TestMethods(TestCase):
             A = np.char.array([b'\\u03a3'])
             assert_(A.decode('unicode-escape')[0] == '\u03a3')
         else:
-            A = np.char.array(['736563726574206d657373616765'])
-            assert_(A.decode('hex_codec')[0] == 'secret message')
+            with suppress_warnings() as sup:
+                if sys.py3kwarning:
+                    sup.filter(DeprecationWarning, "'hex_codec'")
+                A = np.char.array(['736563726574206d657373616765'])
+                assert_(A.decode('hex_codec')[0] == 'secret message')
 
     def test_encode(self):
         B = self.B.encode('unicode_escape')
@@ -579,7 +583,7 @@ class TestMethods(TestCase):
         def fail():
             self.A.isnumeric()
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
         assert_(issubclass(self.B.isnumeric().dtype.type, np.bool_))
         assert_array_equal(self.B.isnumeric(), [
                 [False, False], [True, False], [False, False]])
@@ -589,14 +593,14 @@ class TestMethods(TestCase):
         def fail():
             self.A.isdecimal()
 
-        self.assertRaises(TypeError, fail)
+        assert_raises(TypeError, fail)
         assert_(issubclass(self.B.isdecimal().dtype.type, np.bool_))
         assert_array_equal(self.B.isdecimal(), [
                 [False, False], [True, False], [False, False]])
 
 
-class TestOperations(TestCase):
-    def setUp(self):
+class TestOperations(object):
+    def setup(self):
         self.A = np.array([['abc', '123'],
                            ['789', 'xyz']]).view(np.chararray)
         self.B = np.array([['efg', '456'],
